#include <windows.h>
#include <stdio.h>
#include "AgatRTFaxImageCodec.h"
#include "utils.h"

void PrintUsage( char **argv)
{
	char *chPtr;

	if(( chPtr= ::strrchr( argv[0], '\\'))== 0)
		chPtr= argv[0];
	else
		chPtr++;
	::printf( "Converter  from BMP image to Huffman code\n");
	::printf( "Usage: %s [/R:F|S] [/S] <BmpFileName> [HuffmanFileName]\n", chPtr);
	::printf( "[/R:F|S] - resolution mode F - fine, S - standart (standart by default)\n");
	::printf( "[/S] - need stretch mode ( no - by default)\n");
	::printf( "<BmpFileName> - BMP image\n");
	::printf( "[HuffmanFileName] - file with data code by Huffman.\n");
}

DWORD dwDecodeArguments( int argc, char **argv, TBmpToHuffmanParams *lpEncodeParams)
{
	char *pszBmpFileName= 0, *pszHfmFileName= 0;

	// Check input params
	if(( argc< 2)&&( argc> 5))
	{
		PrintUsage( argv);
		return ERROR_INVALID_PARAMETER;
	}
	for( int i= 1; i< argc; i++)
	{
		if( ::memcmp( argv[i], "/R:", 3)== 0)
		{
			if( argv[i][3]== 'S')
				lpEncodeParams->dwResolution= 0;
			else
			{
				if( argv[i][3]== 'F')
					lpEncodeParams->dwResolution= 1;
				else
				{
					::printf( "Invalid parameter \'%s\'.", argv[i]);
					return ERROR_INVALID_PARAMETER;
				}
			}
			continue;
		}
		if( ::memcmp( argv[i], "/S", 2)== 0)
		{
			lpEncodeParams->dwNeedStretch= 1;
			continue;
		}
	}
	for( int i= 1; i< argc; i++)
	{
		if(( ::memcmp( argv[i], "/R:", 3)!= 0)&&
			( ::memcmp( argv[i], "/S", 2)!= 0))
		{
			if( pszBmpFileName== 0)
			{
				pszBmpFileName= argv[i];
				continue;
			}
			if( pszHfmFileName== 0)
			{
				pszHfmFileName= argv[i];
				continue;
			}
		}
	}
	if( pszBmpFileName== 0)
	{
		::printf( "<BmpFileName> parameter not found.\n");
		return ERROR_INVALID_PARAMETER;
	}
	if( dwFileExist( pszBmpFileName)== 0)
	{
		::printf( "BMP image file \'%s\' not found.\n", pszBmpFileName);
		return ERROR_INVALID_PARAMETER;
	}
	::lstrcpy( lpEncodeParams->pszBmpFileName, pszBmpFileName);
	if( pszHfmFileName== 0)
	{
		::lstrcpy( lpEncodeParams->pszHuffmanFileName, lpEncodeParams->pszBmpFileName);
		SetExtensionToFileName( lpEncodeParams->pszHuffmanFileName, "hfm");
	}
	else
		::lstrcpy( lpEncodeParams->pszHuffmanFileName, pszHfmFileName);
	return 0;
}

void main( int argc, char **argv)
{
	TBmpToHuffmanParams EncodeParams= {0};

	if( dwDecodeArguments( argc, argv, &EncodeParams)!= 0)
		return;

	::printf( "Encode \'%s\' -> \'%s\'\n", EncodeParams.pszBmpFileName, EncodeParams.pszHuffmanFileName);
	char pszGraphMode[2][64]= {"Standart", "Fine"};
	char pszStretchMode[2][64]= {"No", "Yes"};
	::printf( "Graphics mode \'%s\', Stretch image \'%s\'\n", 
			pszGraphMode[EncodeParams.dwResolution], pszStretchMode[EncodeParams.dwNeedStretch]);
	DWORD dwError;
	if(( dwError= dwAFICBmpToFax( &EncodeParams))!= 0)
	{
		::printf( "Error found %d\n", dwError);
		return;
	}
	::printf( "Encoder have a success.\n");
}

